@@ -1,15 +1,26 @@
 OFFSET_ZEROBASED_INDEX = 1
+import uuid
+import coolname
+from numpy import isin
 
 class Task:
 
-    def __init__(self, id, name, effort, progress = 0.0):
+    DEFAULT_EFFORT = 1
+
+    def __init__(self, id = uuid.uuid4(), name = coolname.generate_slug(2), effort = 1, progress = 0.0, start = None, end = None,):
         self._id = id
         self._name = name
-        self._effort = effort
+
+        self._effort = None
+        if isinstance(effort, int) and effort >= Task.DEFAULT_EFFORT:
+            self._effort = effort
+
         self._pre = []
         self._post = []
 
         self._progress = progress
+        self._start = start
+        self._finish = end
 
         self._es = None
         self._lf = None
@@ -26,17 +37,23 @@ class Task:
     def name(self):
         return self._name
 
+    def set_name(self, name):
+        self._name = name
+
     def effort(self):
-        return self._effort
+        return self.effort_numerical()
 
     def effort_numerical(self):
         if not isinstance(self._effort, int):
-            return 0
+            return 1
         return self._effort
 
     def progress(self):
         return self._progress
 
+    def set_progress(self, progress):
+        self._progress = progress
+
     def earliest_start(self):
         if not self._es:
             if not self._pre:
@@ -62,14 +79,28 @@ class Task:
         return self._lf
 
     def start(self):
-        return self.earliest_start()
+        if self._start == None:
+            return self.earliest_start()
+
+        return self._start
+
+    def set_start(self, start):
+        self._start = start
+
+    def set_end(self, end):
+        self._end = end
 
     def end(self):
-        return self.start() + self.__effort_offset()
+        if self._finish == None:
+            return self.start() + self.__effort_offset()
+        
+        return self._finish
 
     def successors(self):
         return self._post
 
     def predecessors(self):
         return self._pre
-        
\ No newline at end of file
+        
+    def is_on_critical_path(self):
+        return self.latest_finish() - self.earliest_start() == self.__effort_offset()
\ No newline at end of file
